import QtQuick 1.0

// ****************** Start About Box **********************
Rectangle{
    id:aboutBox
    property string logoFilename: _appLogo
    property int fontSize :  (640+360)/50
    property int closeButtonSize: (640+360)/15;
    property int fadeInterval: 500
    property string text: qsTr("<b>"+_appName+"</b><br/> Version "+_appVersion + "<br/>" + _copyRight+"<br/>")+
                          qsTr("All Rights Reserved<br/>support@gsoftteam.com<br/>");
    property Item toolbar0
    property bool allowSocial: (_forChina=="false")
    opacity:0
    visible:(opacity!=0)
    border{
        color: "lightslategray"
        width: 3;
    }

    x:20*parent.width/((parent.height>parent.width)?360:640);
    y:20*parent.height/((parent.height>parent.width)?640:360);
    width: (parent.height>parent.width)?(360-40):(640-(56+closeButtonSize));
    height: (parent.height>parent.width)?(640-(56+closeButtonSize)):(360-40);
    transform: Scale {
        origin.x: 0;
        origin.y: 0;
        xScale: parent.width/((parent.height>parent.width)?360:640);
        yScale:parent.height/((parent.height>parent.width)?640:360)
    }

    radius:20
    z: 22
    anchors.topMargin: 20
    anchors.bottomMargin: {
        if (parent.height<parent.width) 20;
        else 36+closeButtonSize;
    }

    gradient: Gradient {
        GradientStop { position: 0.0; color: "#C0DEED" }
        GradientStop { position: 0.5; color: "azure" }
        GradientStop { position: 1.0; color: "#C0DEED" }
    }

    function show(){
        aboutBox.state="revealed";
    }
    function hide(){
        aboutBox.state="dissolved";
    }

    Rectangle{
        x:-20-parent.parent.width*0.25
        y:-20-parent.parent.height*0.25
        width:parent.parent.width*2
        height: parent.parent.height*2
        color:"darkgray"
        opacity: parent.visible?0.55:0.0;
        z:-999
    }

    Image{
        id:logoImage
        asynchronous: false
        anchors.verticalCenter:aboutBox.verticalCenter;
        anchors.verticalCenterOffset:{
            if (parent.height<parent.width) 0;
            else -aboutBox.height/3;
        }
        anchors.horizontalCenter: aboutBox.horizontalCenter;
        anchors.horizontalCenterOffset:{
            if (parent.height<parent.width) -aboutBox.width/3.6;
            else 0;
        }
        source:aboutBox.logoFilename
        width: ((parent.width>parent.height)?parent.height*(1.7-parent.height/parent.width):parent.width*(1.4-parent.width/parent.height))*0.6;
        height: ((parent.width>parent.height)?parent.height*(1.7-parent.height/parent.width):parent.width*(1.4-parent.width/parent.height))*0.6;
    }
    Text {
        id: aboutTxt
        width:{ if (parent.height<parent.width) parent.width/2.2;else parent.width;}
        anchors.top: { if (parent.height<parent.width) aboutBox.top; else logoImage.bottom;}
        anchors.topMargin:{ if (parent.height<parent.width) 10; else parent.height*0.03;}
        anchors.left: { if (parent.height<parent.width)  logoImage.right; else aboutBox.left;}
        anchors.leftMargin:{ if (parent.height<parent.width) 5 ;else 10;}
        wrapMode:Text.WordWrap
        horizontalAlignment:Text.AlignHCenter
        font.pixelSize:{ if (parent.width>parent.height){
                if (parent.height/parent.width>0.65)
                    fontSize*0.85; else fontSize;
            }else
            {
                if (parent.width/parent.height>0.65)
                    fontSize*0.85; else fontSize;

            }
        }
        text:qsTr(aboutBox.text);
    }
    CloseButton{
        id:hideAbout
        y:0;
        z:30
        size: closeButtonSize;
        enabled:true
        onClicked: hide();
    }
    MouseArea{
        anchors.fill: parent
    }


    Grid {
        id: aboutGrid
        property int buttonSize: (parent.height<parent.width)?parent.width/1.7/4.5:parent.width/4.5;
        width: (parent.height>parent.width)?(aboutTxt.width-160):(aboutTxt.width-80)
        anchors{
            left: (parent.height>parent.width)?aboutBox.left:logoImage.right
            leftMargin: (parent.height>parent.width)?80:50
            top: aboutTxt.bottom
            topMargin:10;
            bottom: aboutBox.bottom
            bottomMargin:10;
        }

        rows: 3
        columns:1

        parent: aboutBox

        spacing: (parent.height<parent.width)? (parent.width/2-buttonSize*3)/16:(parent.width-buttonSize*3)/16

        ImageButton{
            id: gSoftTeamButton
            imageFilename: "more.png";
            width: aboutGrid.width
            height: aboutGrid.height/3.5
            onClicked:{
                if(_channelId=="551")Qt.openUrlExternally("http://store.ovi.mobi/publisher/G+Soft+Team/");
                if(_channelId=="559")Qt.openUrlExternally("https://market.android.com/developer?pub=G+Soft+Team");
            }
        }
        ImageButton{
            id: facebookButton
            imageFilename: "facebook.png"
            width: aboutGrid.width
            height: aboutGrid.height/3.5
            visible: allowSocial
            onClicked: { Qt.openUrlExternally("http://m.facebook.com/GSoftTeam?v=feed");}
        }
        ImageButton{
            id: twitterButton
            imageFilename: "twitter.png"
            width: aboutGrid.width
            height: aboutGrid.height/3.5
            visible: allowSocial
            onClicked: { Qt.openUrlExternally("http://mobile.twitter.com/GSoftTeam");}
        }
    }
    states: [
        State {
            name: "dissolved"
            PropertyChanges {
                target: aboutBox
                scale: 0.7
            }
            PropertyChanges {
                target: aboutBox
                opacity: 0
            }

        },
        State {
            name: "revealed"
            PropertyChanges {
                target: aboutBox
                scale: 1.0
            }
            PropertyChanges {
                target: aboutBox
                opacity: 1.0
            }
        }

    ]
    Component.onCompleted: {
        aboutBox.state="dissolved";
    }
    transitions: [
        Transition {
            from: "revealed"
            to: "dissolved"
            NumberAnimation { target: aboutBox; property: "scale"; duration: aboutBox.fadeInterval; }
            NumberAnimation { target: aboutBox; property: "opacity"; duration:aboutBox.fadeInterval;}
        },
        Transition {
            from: "dissolved"
            to: "revealed"
            NumberAnimation { target: aboutBox; property: "scale"; duration: aboutBox.fadeInterval; }
            NumberAnimation { target: aboutBox; property: "opacity"; duration:aboutBox.fadeInterval;}
        }

    ]

}
// ***************** End About Box *************************
