import QtQuick 1.0
import Qt.labs.particles 1.0

Rectangle {
    id:container
    property int pictureID: 1
    property string pictureFile: ""
    property string fruitName: ""
    property int col:1
    property int row:1
    property int borderWidth: 15
    property int xcenter:0;
    property int ycenter:0;
    property string initialBorderColor: "transparent"
    property int rotationInterval:105
    signal click(int col,int row)
    signal verifyMatch()
    width: 100
    height: 62
    border.width: borderWidth
    border.color: initialBorderColor
    color:"paleturquoise"
    clip:true

    function hide(){
        hidingTimer.stop();
        hidingTimer.start();
    }

    transform: Rotation{
        id:rotationContainer;
        origin.x:container.width/2
        origin.y:0
        axis.x:0
        axis.y:1
        axis.z:0
        angle:0
    }

    //    Rectangle{
    //        color:"transparent"
    //        anchors.fill: parent

    Image {
        id: blockImage
        anchors.fill: parent
        anchors.bottomMargin:0;
        clip:true;
        smooth:true;
        source: container.pictureFile
    }
    Image{
        id:backImage
        anchors.fill:parent
        clip:true;
        smooth: true;
        fillMode: Image.Stretch;
        source:"backblock.png"
    }

    Rectangle{
        id:imageNameBox
        width:parent.width;
        height:imageName.height+6;
        anchors.bottom:parent.bottom
        visible:false;
        color:"transparent"
        Text{
            id:imageName
            anchors.centerIn:parent
            font.pixelSize:container.width/Math.max(12,text.length*0.6);
            text:fruitName
        }
    }
    MouseArea{
        anchors.fill: parent
        onClicked:click(col,row);
    }
    Particles {
        id: particles

        width: 20; height: 20
        anchors.centerIn: parent

        emissionRate: 0
        lifeSpan: 2000; lifeSpanDeviation: 400
        angle: 0; angleDeviation: 360;
        velocity: 100; velocityDeviation: 40
        source:"Star.gif";

    }
    Component.onCompleted: {container.state="hidden";}
    states: [
        State {
            name: "hidden"

            PropertyChanges {
                target: rotationContainer
                angle:0
            }
        },
        State {
            name: "shown"
            PropertyChanges {
                target: rotationContainer
                angle:0
            }
        },
        State {
            name: "hiddenShown"
            PropertyChanges {
                target: rotationContainer
                angle:90
            }
        },
        State {
            name: "shownHidden"
            PropertyChanges {
                target: rotationContainer
                angle:90
            }
        },
        State {
            name: "die"
            PropertyChanges {
                target: container
                width:0
            }
            PropertyChanges {
                target: container
                height:0
            }
            PropertyChanges {
                target: container
                x:xcenter
            }
            PropertyChanges {
                target: container
                y:ycenter
            }
            PropertyChanges {
                target: container
                opacity:0.4
            }

        },
        State {
            name: "bigger"
            PropertyChanges {
                target: container
                width:300
            }
            PropertyChanges {
                target: container
                z:30
            }
            PropertyChanges {
                target: container
                height:300+imageNameBox.height
            }
            PropertyChanges {
                target: blockImage
                anchors.bottomMargin:imageNameBox.height
            }
            PropertyChanges {
                target: container
                x:xcenter
            }
            PropertyChanges {
                target: container
                y:ycenter
            }
            StateChangeScript{
                script:{ imageNameBox.visible=true;
                    container.destroy(3000);}
            }
        }
    ]

    transitions: [Transition {
            from:"shown"
            to:"die"
            NumberAnimation { target:container;properties: "x,y,width,height,opacity";easing.type: Easing.InOutQuad; duration:1200 }
            ScriptAction{script:{
                    particles.burst(70);
                    container.destroy(2500);}
            }
        },
        Transition{from:""
            to:"bigger"
            NumberAnimation { target:blockImage;properties: "anchors.bottomMargin";easing.type: Easing.InOutQuad; duration:700 }
            NumberAnimation { target:container;properties: "x,y,z,width,height";easing.type: Easing.InOutQuad; duration:1200 }
        },
        Transition{
            from:"hidden"
            to:"hiddenShown"
            NumberAnimation { target: rotationContainer; property: "angle"; to: 90;easing.type: Easing.OutQuad; duration: rotationInterval }
            ScriptAction{script:{showTimer.stop();showTimer.start();}}
        },
        Transition{
            from:"hiddenShown"
            to:"shown"
            NumberAnimation { target: rotationContainer; property: "angle"; to: 0;easing.type: Easing.InQuad; duration: rotationInterval }
            ScriptAction{script:{backImage.visible=false;
                    verifyMatchTimer.stop();
                    verifyMatchTimer.start();
                }
            }
        },
        Transition{
            from:"shown"
            to:"shownHidden"
            NumberAnimation { target: rotationContainer; property: "angle"; to: 90;easing.type: Easing.OutQuad; duration: rotationInterval }
            ScriptAction{script:{hideTimer.stop();hideTimer.start();}}
        },
        Transition{
            from:"shownHidden"
            to:"hidden"
            NumberAnimation { target: rotationContainer; property: "angle"; to: 0;easing.type: Easing.InQuad; duration: rotationInterval }
            ScriptAction{script:backImage.visible=true}
        }

    ]
    Timer{
        id:showTimer
        running:false
        interval: rotationInterval*1.05
        repeat:false
        onTriggered: { container.state="shown";}
    }
    Timer{
        id:hideTimer
        running:false
        interval: rotationInterval*1.05
        repeat:false
        onTriggered: { container.state="hidden";}
    }
    Timer{
        id:verifyMatchTimer
        running:false
        interval: rotationInterval*4
        repeat:false
        onTriggered:{verifyMatch();}
    }
    Timer{
        id:hidingTimer
        running:false
        interval: rotationInterval*0.8
        repeat:false
        onTriggered:{container.state="shownHidden";}
    }
}
