import QtQuick 1.0

Rectangle {
    id: interstitialWrapper
    width: (parent.height>parent.width)?360:640;
    height: (parent.height>parent.width)?640:360;
    transform: Scale { origin.x: 0; origin.y: 0; xScale: parent.width/width; yScale:parent.height/height}

    //    color: "#C0DEED"
    property alias messageText: sponsorText.text
    property int skipIn:  0
    property bool quitAfter: false

    //screen width is important for getting the right ads showing
    property alias screenWidth: ad.screenWidth
    property alias screenHeight: ad.screenHeight

    //private
    property int __skippingIn:  -1

    //aliased to the ad properties so they can be set here but reflected in the child
    property alias appid: ad.appid

    gradient: Gradient {
        GradientStop { position: 0.0; color: "#C0DEED" }
        GradientStop { position: 0.5; color: "azure" }
        GradientStop { position: 1.0; color: "#C0DEED" }
    }



    function loadAd() {
        ad.loadAd();
        //disable skip button and restart timer
        if(skipIn > 0) {
            __skippingIn = skipIn
            skipButton.disabled = true;
            skipTimer.start();
        }

    }

    function hide() {
        visible = false;
    }

    function show() {
        visible = true;
        //        loadAd();
    }

    MouseArea{
        anchors.fill: parent
    }

    Rectangle{
        id:ownAdRect
        anchors.top:parent.top
        height:(parent.height>parent.width)? parent.height*0.15:parent.height*0.18;
        width: parent.width
        visible: (ad.receivedAd==true)
        color:"transparent"
        MyAd{
            id:ownAd
            height:parent.height
            width: parent.width
            visible: ad.receivedAd
            fontSize: 16
            //            height:parent.height*adWrapper.parent.height/adWrapper.height;
            //            width: parent.width*adWrapper.parent.width/adWrapper.width;
            //            transform: Scale { origin.x: 0; origin.y: 0; xScale: adWrapper.width/adWrapper.parent.width; yScale:adWrapper.height/adWrapper.parent.height;}
        }
    }

    Rectangle{
        anchors.top: ownAd.visible?ownAdRect.bottom:parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        color:"transparent"
        Text {
            id: sponsorText
            text: ad.receivedAd?("We are able to provide you with a full free version of this "+_appType+" thanks to our sponsors:"):_ownAdAboveMessage;
            anchors.top:parent.top
            anchors.topMargin: 5
            anchors.left: parent.left
            anchors.leftMargin: 15
            anchors.right: parent.right
            anchors.rightMargin:15
            anchors.bottom: adRect.top
            anchors.bottomMargin: 5
            font.pixelSize: 20*(ad.receivedAd?1:1.5);
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: ownAd.visible?Text.AlignBottom:Text.AlignVCenter
            height:(parent.height>parent.width)? parent.height*0.16:parent.height*0.22;
            wrapMode: Text.WordWrap
            color: "black"
        }

        Rectangle{
            id:adRect
            width: parent.width
            height: (((parent.height>parent.width)?105:80))*(ad.receivedAd?1:1.25);
            anchors.centerIn: parent
            anchors.verticalCenterOffset: -parent.height/7
            color:"orange"
            InnerActiveAd {
                id: ad
                anchors.centerIn: parent
                transform: Scale { origin.x: 0; origin.y: ad.height/2; xScale: interstitialWrapper.width/interstitialWrapper.parent.width; yScale:interstitialWrapper.height/interstitialWrapper.parent.height;}
                visible: ad.receivedAd
            }
            MouseArea{
                anchors.fill: adRect
                onClicked: {
                    console.log("visit ad button pressed");
                    if(ad.receivedAd){
                        ad.adClicked();
                    }
                    else
                    {
                        Qt.openUrlExternally(_ownAdLink);
                    }

                    if(quitAfter==true){
                        Qt.quit();
                    }
                    interstitialWrapper.hide();
                }
                enabled: ad.receivedAd
            }
            MyAd{
                id:replacementAdRect
                height:parent.height*interstitialWrapper.parent.height/interstitialWrapper.height;
                width: parent.width*interstitialWrapper.parent.width/interstitialWrapper.width;
                visible: !ad.receivedAd
                transform: Scale { origin.x: 0; origin.y: 0; xScale: interstitialWrapper.width/interstitialWrapper.parent.width; yScale:interstitialWrapper.height/interstitialWrapper.parent.height;}
            }
        }

        Text {
            id: sponsorText2
            text: ad.receivedAd?("Please support us by clicking on the banner !"):(_channelId=="551"?"Please support us by buying the full version of this "+_appType+" !":"They're free!");
            anchors.top:adRect.bottom
            anchors.topMargin: 5
            anchors.left: parent.left
            anchors.leftMargin: 15
            anchors.right: parent.right
            anchors.rightMargin:15
            font.pixelSize: 22
            horizontalAlignment: Text.AlignHCenter
            height:(parent.height>parent.width)? parent.height*0.16:parent.height*0.22;
            wrapMode: Text.Wrap
            color: "black"
        }


        Text{
            id:adText
            anchors.bottom: goButton.top
            anchors.bottomMargin: (interstitialWrapper.height>interstitialWrapper.width)?15:5;
            anchors.left: parent.left
            anchors.leftMargin: 10
            width: interstitialWrapper.width/2
            text:__skippingIn > 0 ? "Skip in " + __skippingIn + " sec(s)" : ""
            font.pixelSize: 17
            smooth: true
        }
        Text{
            id:adText2
            anchors.bottom: goButton.top
            anchors.bottomMargin: (interstitialWrapper.height>interstitialWrapper.width)?15:5;
            anchors.right: parent.right
            anchors.rightMargin: 10
            //        width: adWrapper.width
            text:"ads by <b>inneractive</b>"
            horizontalAlignment: Text.AlignRight
            font.pixelSize: 17
            visible: ad.receivedAd
            color:"#B64689"
            smooth:true
        }

        ImageButton{
            id: skipButton
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: (interstitialWrapper.height>interstitialWrapper.width)?0:(-180);
            y:parent.height-90;
            property bool disabled: false
            width: 210*((interstitialWrapper.height>interstitialWrapper.width)?1.25:1.1);
            height: 68*((interstitialWrapper.height>interstitialWrapper.width)?1.25:1.1);
            imageFilename: disabled?"skipButtonDisabled.png":"skipButton.png";
            onClicked: {
                console.log("skip pressed");
                if(skipButton.disabled == false)
                {
                    if(quitAfter==true){
                        Qt.quit();
                    }
                    else
                    {
                        interstitialWrapper.hide();
                    }
                }
            }
        }
        ImageButton{
            id: goButton
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: (interstitialWrapper.height>interstitialWrapper.width)?(0):(180);
            y:(parent.height>parent.width)?parent.height-180:parent.height-90;
            width: 210*((interstitialWrapper.height>interstitialWrapper.width)?1.25:1.1);
            height: 68*((interstitialWrapper.height>interstitialWrapper.width)?1.25:1.1);
            imageFilename: "goButton.png"
            onClicked: {
                console.log("visit ad button pressed");
                if(ad.receivedAd){
                    ad.adClicked();
                }
                else
                {
                    Qt.openUrlExternally(_ownAdLink);
                }

                if(quitAfter==true){
                    Qt.quit();
                }
                interstitialWrapper.hide();
            }
        }
    }

    Timer {
        id: skipTimer
        interval: 1000      //countdown timer
        repeat: true

        onTriggered: {
            if(__skippingIn == 0) {
                skipTimer.stop();
                console.log("Ad finished");
                skipButton.disabled = false;

            } else
                __skippingIn = __skippingIn - 1;
        }
    }
}
