import QtQuick 1.0

Rectangle {
    id:introWrapper
    width: (parent.height>parent.width)?360:640;
    height: (parent.height>parent.width)?640:360;
    transform: Scale { origin.x: 0; origin.y: 0; xScale: parent.width/width; yScale:parent.height/height}
    visible: true
    color: "#C0DEED"
    z:9999

    property bool forceConnection: false

    property real portraitFactor: 0.75
    property real landscapeFactor: 1.1
    property bool loading: true


    function onNoICFound(){
        buttonsGrid.columns=1;
        cancelButton.visible=false;
        message.text="No Internet connection found. Please configure the connection and try again. "
    }
    gradient: Gradient {
        GradientStop { position: 0.0; color: "#C0DEED" }
        GradientStop { position: 0.5; color: "azure" }
        GradientStop { position: 1.0; color: "#C0DEED" }
    }

    MouseArea{
        anchors.fill: parent
    }
    Item{
        id:mainPart
        anchors.fill: parent
        anchors.bottomMargin: (parent.height>parent.width)?parent.height*0.45:parent.height*0.1;

        Image{
            id:logo
            anchors{
                fill: parent
                leftMargin: (introWrapper.height>introWrapper.width)?parent.width*0.15:parent.width*0.05;
                rightMargin: (introWrapper.height>introWrapper.width)?parent.width*0.15:parent.width*0.6;
                topMargin: parent.height*0.05
                bottomMargin: (introWrapper.height>introWrapper.width)?parent.height*0.25:(adManager.icReq?parent.height*0.4:parent.height*0.3);
            }
            fillMode:Image.Stretch
            source: "../"+_appLogo
        }

        Rectangle{
            id:content
            anchors{
                top: (introWrapper.height>introWrapper.width)?logo.bottom:parent.top;
                left: (introWrapper.height>introWrapper.width)?parent.left:logo.right;
                right: parent.right
                topMargin: 20
            }
            width: (introWrapper.height>introWrapper.width)?parent.width:parent.width/2;
            height: 150
            color:"transparent"

            Text{
                id:appText
                text:_appName+" "+_appVersion
                anchors{
                    left: parent.left
                    right: parent.right
                    top: parent.top
                    topMargin: 20
                    margins: 30
                }
                width: parent.width
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.pixelSize: 28
            }
            Text{
                id:copyright
                text:_copyRight
                anchors.horizontalCenter: appText.horizontalCenter
                anchors.top: appText.bottom
                anchors.topMargin: 8
                verticalAlignment: Text.AlignVCenter
                font.bold: true
                font.pixelSize: 15
            }
            AnimatedImage{
                id:loadingImg
                asynchronous: true
                anchors.horizontalCenter: copyright.horizontalCenter
                anchors.top: copyright.bottom
                anchors.topMargin: 20
                width:150;
                height: 40;
                source:"loading.gif"
                visible: loading
            }
        }
    }
    Rectangle{
        id:messageBox
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom:parent.bottom
        width: parent.width
        height: {
            if(buttonsGrid.columns==1){
                (parent.height>parent.width)?180:155
            }
            else
            {
                135
            }
        }
        color:Qt.rgba(1,1,1,0.7)
        visible:forceConnection
        Text{
            id:message
            text:"This application requires an Internet connection."
            anchors.fill: parent
            anchors.margins: 10
            font.bold: true
            font.pixelSize: 25
            wrapMode: Text.WordWrap
        }

        Grid{
            id:buttonsGrid
            rows:1
            columns: 2
            flow:Grid.LeftToRight
            spacing:(introWrapper.height>introWrapper.width)?20:120;
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.bottom: parent.bottom
            anchors.bottomMargin:10;

            ImageButton{
                id: okButton

                property bool disabled: false
                width: 210*((introWrapper.height>introWrapper.width)?portraitFactor:landscapeFactor);
                height: 70*((introWrapper.height>introWrapper.width)?portraitFactor:landscapeFactor);
                imageFilename: "okButton.png";
                onClicked: {
                    if(buttonsGrid.columns==2){
                        var isOpened=_appManager.initConnection();
                        adManager.isInternetConnectionOn("finalCheck");
                        console.debug("Was Connection opened ? "+isOpened);
                        console.debug("Is Internet on "+adManager.internetOn);
                    }
                    else
                    {
                        Qt.quit();
                    }
                }
            }
            ImageButton{
                id: cancelButton
                width: 210*((introWrapper.height>introWrapper.width)?portraitFactor:landscapeFactor);
                height: 70*((introWrapper.height>introWrapper.width)?portraitFactor:landscapeFactor);
                imageFilename: "cancelButton.png"
                onClicked: {
                    Qt.quit();
                }
            }
        }
    }
}
