import QtQuick 1.0
import "kanjiBlocks.js" as Logic
import "appBase"

Rectangle {
    id:screen
    property string gameName: "Kanji Blocks"
    property int closeButtonSize:(screen.width+screen.height)/15;
    property int fontSize: (screen.width+screen.height)/45;
    height: 639
    width: 361

    color:'darkkhaki'
    onHeightChanged: {
        Logic.init();
        Logic.orientationChanged();
    }
    Component.onCompleted: {
        Logic.orientationChanged();
    }

    Image{
        anchors.fill: parent
        source: "bg.png"
        fillMode: Image.Tile
    }

    AdManager{
        id:adManager
    }

    Intro{
        id:intro
    }


    Rectangle{
        id:winBox;
        anchors.centerIn: parent
        width:parent.width*0.80;
        height:parent.height/2
        color:"antiquewhite"
        opacity:0.0
        visible:{if (opacity==0.0) false;
                       else true;}
        border.color: "black"
        border.width: 2;
        Text {
            id: winText
            anchors.centerIn: parent
            font.pixelSize: 48;
            smooth:true;
            text: qsTr(" You won! ");
        }
        MouseArea{
            anchors.fill: parent
            onClicked: winBox.state="Hide";
        }

        states: [
            State {
                name: "Show"
                PropertyChanges {
                    target: winBox
                    opacity:1.0
               }
            },
            State {
                name: "Hide"
                PropertyChanges {
                    target: winBox
                    opacity:0.0
               }

            }
        ]
        transitions: Transition{
            NumberAnimation{target:winBox;property:"opacity";easing.type: Easing.Linear;duration:800;}
        }
    }
    /*Message Box BEGIN*/
    Rectangle{
        id:messageBox
        height:Logic.timebarHeight+3
        width:parent.width
        anchors.left:parent.left
        anchors.right:parent.right
        anchors.rightMargin:0;
        anchors.top:parent.top
        color:"lemonchiffon"
        border.width: 1
        border.color: "gray"
        opacity:0.7
    }
    Rectangle{
        id:timeTxtBox;
        width:timeTxt.width+10;
        height:timeTxt.height+2;
        anchors.right:movesTxtBox.left
        anchors.rightMargin:10
        anchors.top: messageBox.top
        anchors.topMargin: 12;
        radius:5
        color:"white"
        border.color: "black"
        border.width: 1
        Text{
            id:timeTxt;
            x:3;
            y:0;
            anchors.centerIn: parent
            color:"black"
            font.pixelSize: 22;
            font.bold: true;
            text: qsTr("00:00")
        }
    }
    Rectangle{
        id:movesTxtBox;
        width:movesTxt.width+10;
        height:movesTxt.height+2;
        anchors.right:messageBox.right
        anchors.rightMargin: 10
        anchors.top: messageBox.top
        anchors.topMargin: 12;
        radius:5
        color:"white"
        border.color: "black"
        border.width: 1
        Text{
            id:movesTxt;
            x:3;
            y:0;
            anchors.centerIn: parent
            color:"black"
            font.pixelSize: 22;
            font.bold: true;
            text: qsTr("Moves:0")
        }
    }
    Text{
        id:kanji1Txt
        anchors.top:messageBox.top
        anchors.left:messageBox.left
        anchors.leftMargin: 10
        font.pixelSize: messageBox.height/3
        text:'1:'
    }
    Text{
        id:kanji2Txt
        anchors.top:kanji1Txt.bottom
        anchors.left:messageBox.left
        anchors.leftMargin: 10
        font.pixelSize: messageBox.height/3
        text:'2:'
    }

    /*Message Box END*/

    ListModel{
        id:hModel
    }
    HighscoreBox{
        id:highscoreBox
        highScoreModel:hModel
        fontSize:screen.fontSize
        onVisibleChanged: {
            if(visible==false){
                adManager.showInterstitial();
            }
        }
    }

    Rectangle{
        id:fog
        z:22
        color:"silver"
        anchors.fill: screen
        opacity: 0.0;
    }

    HelpBox{
        id:helpBox
        toolbar0: toolbar
        fontSize:screen.fontSize
        closeButtonSize: screen.closeButtonSize
        onHideFunction: Logic.hideHelpAction();
        text:  "<h1><center>Help</center></h1> <p>"+_appHelp+"</p>";
        onVisibleChanged: {
            if(visible==false){
                adManager.showInterstitial();
            }
        }

    }
    AboutBox{
        id:aboutBox
        onVisibleChanged: {
            if(visible==false){
                fog.opacity=0;
                Logic.menuOpen=false;
                adManager.showInterstitial();
            }
        }
    }
    PauseBox{
        id:pauseBox
        toolbar0:toolbar
        fontSize:screen.fontSize
        closeButtonSize: screen.closeButtonSize
        onHideFunction: Logic.hidePauseAction();
        text:"<h2>Game Paused</h2>";
    }



// ***************** Start Toolbar *************************
    Rectangle{
        id:toolbar;
        width:parent.width
        height:54;
        opacity:1;
        color:"khaki";
        border.color: "gray"
        border.width: 2
        anchors.bottom: parent.bottom;
    }

    Grid {
        id: toolbarGrid
        anchors.fill: toolbar
        rows: 1
        columns:4
        parent: toolbar

        anchors.leftMargin:10;//(toolbar.width-columns*helpButton.width)/10;
        anchors.rightMargin: 10;//(toolbar.width-columns*helpButton.width)/10;

        anchors.topMargin:10;//(toolbar.height-rows*helpButton.height)/10;
        anchors.bottomMargin:10;//(toolbar.height-rows*helpButton.height)/10;

        spacing: (columns>rows?((toolbar.width-4*helpButton.width)/4):((toolbar.height-4*helpButton.height)/4));

        PlayButton{
            id: newGameButton
            onClicked:Logic.startNewGame()
        }
        HelpButton{
            id: helpButton
            onClicked: Logic.displayHelp()
        }
        InfoButton{
            id: aboutButton
            onClicked: Logic.displayAbout()
        }
        ExitButton{
            id: quitButton
            onClicked: if (!Logic.gamePaused){
                           adManager.enableQuitAfterAd();
                           adManager.showInterstitial();
                       }
        }
    }
 // ***************** End Toolbar ********************************************

 //****************** Start Dialog ***************************************
    Dialog {
        id: dialog; anchors.centerIn: parent; z: 21
    }

    Dialog {
        id: nameInputDialog

        gradient: Gradient{
            GradientStop{position:0.0;color:"oldlace";}
            GradientStop{position:1.0;color:"moccasin";}
        }
        property int initialWidth: 0
        property alias name: nameInputText.text
        height:screen.height*0.4
        width:(screen.height>screen.width)?screen.width*0.9:screen.width*0.7;
        radius: height*0.2

        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top:parent.top
        anchors.topMargin: parent.height/6

        onClosed: {
            if (nameInputText.text != "")
                Logic.saveHighScore(nameInputText.text);
        }
        Text {
            id: dialogText
            anchors.top:parent.top
            anchors.topMargin: parent.height*0.1
            anchors.left: parent.left
            anchors.leftMargin: parent.width*0.1
            width: parent.width
            height: parent.height*0.5
            font.pixelSize: 26
            wrapMode: Text.WordWrap
            text: "You won!<br/> Please enter your name: "
        }
        Keys.onReturnPressed: {
            if(nameInputText.focus==true){
                nameInputText.closeSoftwareInputPanel();
                nameInputText.focus=false;
            }
        }

        MouseArea {
            anchors.fill: parent
            onClicked: {
                nameInputText.focus=true;
                if (nameInputText.text == "")
                    Logic.showKeyboard();
            }
            onPressed: {
                if(nameInputText.focus==true){
                    nameInputText.closeSoftwareInputPanel();
                    nameInputText.focus=false;
                }
            }

        }

        Rectangle{
            anchors.fill: nameInputText
            anchors.margins: -10;
            color:"white"
            radius:15
        }
        TextInput {
            id: nameInputText
            anchors.top: dialogText.bottom
            anchors.left: parent.left
            anchors.leftMargin: parent.width*0.12
            width:parent.width*0.8
            color:"steelblue"
            focus: false
            autoScroll: false
            font.pixelSize: 30
            maximumLength: 9
        }

        OkButton{
            id:closeHighlight
            size: closeButtonSize/1.25;
            onClicked: {
                nameInputText.closeSoftwareInputPanel();
                nameInputText.focus=false;
                if (nameInputText.text=='') nameInputText.text="Player";
                nameInputDialog.forceClose();
            }
        }
        Timer{
            id: delayKeyboard
            running: false
            repeat:false
            interval:1500
            onTriggered: Logic.nowShowKeyboard();
        }
        Timer{
            id: delayWin
            running: false
            repeat: false
            interval:3000;
            onTriggered: Logic.showWin();
        }

    }

//******************** End Dialog *****************************************

    // paused timer
    Timer{
        id:gameTimer
        property int gameLength: 0
        running:false
        repeat:true
        interval:1000
        onTriggered: Logic.crono();
    }
    //end modified paused
    MouseArea {
        z:99
        anchors.fill: screen
        enabled: nameInputText.focus;
        onPressed: {
            if(nameInputText.focus==true){
                nameInputText.closeSoftwareInputPanel();
                nameInputText.focus=false;
            }
        }
    }


}
